==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grop important:</b> que s’aconselha hòrt de seleccionar un mot clau dens aqueth grop.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'los administrators deu sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'los redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'los vesitaires deu sit public quan mandan un messatge dens un forum.',

	// I
	'icone_creation_groupe_mots' => 'Crear un navèth grop de mots',
	'icone_creation_mots_cles' => 'Crear un mot clau nau',
	'icone_modif_groupe_mots' => 'Modificar aqueth grop de mots',
	'icone_mots_cles' => 'Mots clau',
	'icone_supprimer_groupe_mots' => 'Suprimir aqueth document',
	'icone_voir_tous_mots_cles' => 'Véder tots los mots clau ',
	'info_articles_lies_mot' => 'Los articles ligats a aqueth mot clau',
	'info_changer_nom_groupe' => 'Cambiar lo nom d’aqueth grop:',
	'info_creation_mots_cles' => 'Creatz e configuratz ací los mots clau deu sit',
	'info_dans_groupe' => 'Dens lo grop:',
	'info_delet_mots_cles' => 'Qu’avetz demandat de suprimir lo mot clau
<b>@titre_mot@</b> (@type_mot@). Aqueth mot clau qu’ei ligat a
 <b>@texte_lie@</b>. Que devetz confirmar aquera decision:', # MODIF
	'info_groupe_important' => 'Grop important',
	'info_mots_cles' => 'Los mots clau',
	'info_mots_cles_association' => 'Los mots clau d’aqueth grop que’s pòden associar:',
	'info_oui_suppression_mot_cle' => 'Que vòi suprimir aqueth mot clau definitivament.',
	'info_question_mots_cles' => 'E desiratz d’utilizar los mots clau suu vòste sit?',
	'info_qui_attribue_mot_cle' => 'Los mots d’aqueth grop que pòden estar atribuits per:',
	'info_retirer_mot' => 'Quitar aqueth mot',
	'info_retirer_mots' => 'Quitar tots los mots ',
	'info_rubriques_liees_mot' => 'Las rubricas ligadas a aqueth mot clau',
	'info_selection_un_seul_mot_cle' => 'Que’s pòt seleccionar sonque <b>un mot clau</b> au còp dens aqueth grop.', # MODIF
	'info_supprimer_mot' => 'suprimir aqueth mot',
	'info_titre_mot_cle' => 'Nom o títol deu mot clau',
	'info_un_mot' => 'Sonque un mot au còp',
	'item_ajout_mots_cles' => 'Autorizar que s’ajuste mots clau aus forums',
	'item_non_ajout_mots_cles' => 'Proïbir l’utilizacion deus mots clau dens los forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'N’utilizar pas la configuracion avançada deus grops de mots clau',
	'item_non_utiliser_mots_cles' => 'N’utilizar pas los mots clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuracion avançada deus grops de mots clau',
	'item_utiliser_mots_cles' => 'Utilizar los mots clau',

	// L
	'logo_mot_cle' => 'LÒGO DEU MOT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'E desiratz d’activar la configuracion avançada deus mots clau,
 en indicar per exemple que’s pòt seleccionar un mot unenc
 per grop, qu’un grop ei important...?', # MODIF
	'texte_mots_cles' => 'Mercés aus mots clau que podetz crear ligams tematics entre los vòstes articles
  qué que sia la lor plaça dens las rubricas. Aquò que’vs permet
  d’enriquir la navigacion deu vòste sit, e quitament d’utilizar aqueras proprietats 
  entà personalizar la presentacion deus articles dens las esqueletas. ',
	'texte_mots_cles_dans_forum' => 'E desiratz de perméter l’utilizacion deus mots clau, seleccionables peus vesitaires, dens los forums deu sit public? (Atencion: qu’ei pro complèxe d’utilizar aquera opcion corrèctament.)',
	'texte_nouveau_mot' => 'Mot nau',
	'titre_config_groupe_mots_cles' => 'Configuracion deus grops de mots clau',
	'titre_gauche_mots_edit' => 'MOT NUMÈRO:',
	'titre_mots_cles_dans_forum' => 'Mots clau dens los forums deu sit public',
	'titre_mots_tous' => 'Los mots clau',
	'titre_nouveau_groupe' => 'Grop navèth',
	'titre_page_mots_tous' => 'Mots clau'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grop important:</b> que s’aconselha hòrt de seleccionar un mot clau dens aqueth grop.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'los administrators deu sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'los redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'los vesitaires deu sit public quan mandan un messatge dens un forum.',

	// I
	'icone_creation_groupe_mots' => 'Crear un navèth grop de mots',
	'icone_creation_mots_cles' => 'Crear un mot clau nau',
	'icone_modif_groupe_mots' => 'Modificar aqueth grop de mots',
	'icone_mots_cles' => 'Mots clau',
	'icone_supprimer_groupe_mots' => 'Suprimir aqueth document',
	'icone_voir_tous_mots_cles' => 'Véder tots los mots clau ',
	'info_articles_lies_mot' => 'Los articles ligats a aqueth mot clau',
	'info_changer_nom_groupe' => 'Cambiar lo nom d’aqueth grop:',
	'info_creation_mots_cles' => 'Creatz e configuratz ací los mots clau deu sit',
	'info_dans_groupe' => 'Dens lo grop:',
	'info_delet_mots_cles' => 'Qu’avetz demandat de suprimir lo mot clau
<b>@titre_mot@</b> (@type_mot@). Aqueth mot clau qu’ei ligat a
 <b>@texte_lie@</b>. Que devetz confirmar aquera decision:', # MODIF
	'info_groupe_important' => 'Grop important',
	'info_mots_cles' => 'Los mots clau',
	'info_mots_cles_association' => 'Los mots clau d’aqueth grop que’s pòden associar:',
	'info_oui_suppression_mot_cle' => 'Que vòi suprimir aqueth mot clau definitivament.',
	'info_question_mots_cles' => 'E desiratz d’utilizar los mots clau suu vòste sit?',
	'info_qui_attribue_mot_cle' => 'Los mots d’aqueth grop que pòden estar atribuits per:',
	'info_retirer_mot' => 'Quitar aqueth mot',
	'info_retirer_mots' => 'Quitar tots los mots ',
	'info_rubriques_liees_mot' => 'Las rubricas ligadas a aqueth mot clau',
	'info_selection_un_seul_mot_cle' => 'Que’s pòt seleccionar sonque <b>un mot clau</b> au còp dens aqueth grop.', # MODIF
	'info_supprimer_mot' => 'suprimir aqueth mot',
	'info_titre_mot_cle' => 'Nom o títol deu mot clau',
	'info_un_mot' => 'Sonque un mot au còp',
	'item_ajout_mots_cles' => 'Autorizar que s’ajuste mots clau aus forums',
	'item_non_ajout_mots_cles' => 'Proïbir l’utilizacion deus mots clau dens los forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'N’utilizar pas la configuracion avançada deus grops de mots clau',
	'item_non_utiliser_mots_cles' => 'N’utilizar pas los mots clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuracion avançada deus grops de mots clau',
	'item_utiliser_mots_cles' => 'Utilizar los mots clau',

	// L
	'logo_mot_cle' => 'LÒGO DEU MOT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'E desiratz d’activar la configuracion avançada deus mots clau,
 en indicar per exemple que’s pòt seleccionar un mot unenc
 per grop, qu’un grop ei important...?', # MODIF
	'texte_mots_cles' => 'Mercés aus mots clau que podetz crear ligams tematics entre los vòstes articles
  qué que sia la lor plaça dens las rubricas. Aquò que’vs permet
  d’enriquir la navigacion deu vòste sit, e quitament d’utilizar aqueras proprietats 
  entà personalizar la presentacion deus articles dens las esqueletas. ',
	'texte_mots_cles_dans_forum' => 'E desiratz de perméter l’utilizacion deus mots clau, seleccionables peus vesitaires, dens los forums deu sit public? (Atencion: qu’ei pro complèxe d’utilizar aquera opcion corrèctament.)',
	'texte_nouveau_mot' => 'Mot nau',
	'titre_config_groupe_mots_cles' => 'Configuracion deus grops de mots clau',
	'titre_gauche_mots_edit' => 'MOT NUMÈRO:',
	'titre_mots_cles_dans_forum' => 'Mots clau dens los forums deu sit public',
	'titre_mots_tous' => 'Los mots clau',
	'titre_nouveau_groupe' => 'Grop navèth',
	'titre_page_mots_tous' => 'Mots clau',
];
